==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebTabHeaderConnectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabHeaderConnectionEventArgsDetailDescriptionMetadata } from "./WebTabHeaderConnectionEventArgsDetailDescriptionMetadata";
import { WebTabHeaderConnectionEventArgsDescription } from "./WebTabHeaderConnectionEventArgsDescription";
/**
 * @hidden
 */
var WebTabHeaderConnectionEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebTabHeaderConnectionEventArgsDescriptionMetadata, _super);
    function WebTabHeaderConnectionEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabHeaderConnectionEventArgsDescriptionMetadata.b = function (a) {
        if (WebTabHeaderConnectionEventArgsDescriptionMetadata.a == null) {
            WebTabHeaderConnectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabHeaderConnectionEventArgsDescriptionMetadata.c(WebTabHeaderConnectionEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebTabHeaderConnectionEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebTabHeaderConnectionEventArgsDescriptionMetadata.a);
        WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.d(a);
    };
    WebTabHeaderConnectionEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TabHeaderConnectionEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebTabHeaderConnectionEventArgsDetail");
    };
    WebTabHeaderConnectionEventArgsDescriptionMetadata.d = function (a) {
        WebTabHeaderConnectionEventArgsDescriptionMetadata.b(a);
        a.ac("WebTabHeaderConnectionEventArgs", function () { return new WebTabHeaderConnectionEventArgsDescription(); });
        a.ab("WebTabHeaderConnectionEventArgs", WebTabHeaderConnectionEventArgsDescriptionMetadata.a);
    };
    WebTabHeaderConnectionEventArgsDescriptionMetadata.$t = markType(WebTabHeaderConnectionEventArgsDescriptionMetadata, 'WebTabHeaderConnectionEventArgsDescriptionMetadata');
    WebTabHeaderConnectionEventArgsDescriptionMetadata.a = null;
    return WebTabHeaderConnectionEventArgsDescriptionMetadata;
}(Base));
export { WebTabHeaderConnectionEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebTabHeaderConnectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabHeaderConnectionEventArgsDetailDescriptionMetadata } from "./WebTabHeaderConnectionEventArgsDetailDescriptionMetadata";
import { WebTabHeaderConnectionEventArgsDescription } from "./WebTabHeaderConnectionEventArgsDescription";
/**
 * @hidden
 */
var WebTabHeaderConnectionEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTabHeaderConnectionEventArgsDescriptionMetadata, _super);
    function WebTabHeaderConnectionEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabHeaderConnectionEventArgsDescriptionMetadata.b = function (a) {
        if (WebTabHeaderConnectionEventArgsDescriptionMetadata.a == null) {
            WebTabHeaderConnectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabHeaderConnectionEventArgsDescriptionMetadata.c(WebTabHeaderConnectionEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebTabHeaderConnectionEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebTabHeaderConnectionEventArgsDescriptionMetadata.a);
        WebTabHeaderConnectionEventArgsDetailDescriptionMetadata.d(a);
    };
    WebTabHeaderConnectionEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TabHeaderConnectionEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebTabHeaderConnectionEventArgsDetail");
    };
    WebTabHeaderConnectionEventArgsDescriptionMetadata.d = function (a) {
        WebTabHeaderConnectionEventArgsDescriptionMetadata.b(a);
        a.ae("WebTabHeaderConnectionEventArgs", function () { return new WebTabHeaderConnectionEventArgsDescription(); });
        a.ad("WebTabHeaderConnectionEventArgs", WebTabHeaderConnectionEventArgsDescriptionMetadata.a);
    };
    WebTabHeaderConnectionEventArgsDescriptionMetadata.$t = markType(WebTabHeaderConnectionEventArgsDescriptionMetadata, 'WebTabHeaderConnectionEventArgsDescriptionMetadata');
    WebTabHeaderConnectionEventArgsDescriptionMetadata.a = null;
    return WebTabHeaderConnectionEventArgsDescriptionMetadata;
}(Base));
export { WebTabHeaderConnectionEventArgsDescriptionMetadata };
